@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0305';
+our $VERSION = '0.0306';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -156,12 +156,19 @@ sub generate {
     );
 
     # Try to start the phrase at the beginning of the scale
-    $voice->context($fixed[0]) if $self->tonic;
+    $voice->context([$fixed[0]]) if $self->tonic;
 
     # Get a passage of quasi-random pitches
     my @chosen = map { $voice->rand } 1 .. $num;
 
-    $chosen[0] = $fixed[0] if $self->tonic;
+    if ($self->tonic) {
+        if ($scale eq 'major' || $scale eq 'minor') {
+            $chosen[0] = _closest($chosen[1], [ @fixed[0,2,4] ])
+        }
+        elsif ($scale eq 'pentatonic' || $scale eq 'pminor') {
+            $chosen[0] = _closest($chosen[1], [ @fixed[0,1,2] ])
+        }
+    }
 
     # Intersect with the next-chord pitches
     if ($next_chord) {
@@ -216,7 +223,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0305
+version 0.0306
 
 =head1 SYNOPSIS
 
